..
      Copyright 2016 Huawei Technologies India Pvt Limited.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.


      Convention for heading levels in Neutron devref:
      =======  Heading 0 (reserved for the title in a document)
      -------  Heading 1
      ~~~~~~~  Heading 2
      +++++++  Heading 3
      '''''''  Heading 4
      (Avoid deeper levels because they do not render well.)

===================================================
Welcome to neutron-dynamic-routing's documentation!
===================================================

.. NOTE(amotoki): toctree_only=False is specified in latex_documents
   in doc/source/conf.py to get a better structure of the PDF doc.
   This means the content of this file (index.rst) is NOT rendered
   in the generated PDF file.

.. include:: ../../README.rst

Contents
========

.. toctree::
    :maxdepth: 2

    install/index
    admin/index
    configuration/index
    reference/index
    cli/index
    contributor/index
    install/usecase-ipv6

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
